@@ -24,14 +24,14 @@ final class Twig_TokenParser_Macro extends Twig_TokenParser
     {
         $lineno = $token->getLine();
         $stream = $this->parser->getStream();
-        $name = $stream->expect(Twig_Token::NAME_TYPE)->getValue();
+        $name = $stream->expect(/* Twig_Token::NAME_TYPE */ 5)->getValue();
 
         $arguments = $this->parser->getExpressionParser()->parseArguments(true, true);
 
-        $stream->expect(Twig_Token::BLOCK_END_TYPE);
+        $stream->expect(/* Twig_Token::BLOCK_END_TYPE */ 3);
         $this->parser->pushLocalScope();
         $body = $this->parser->subparse(array($this, 'decideBlockEnd'), true);
-        if ($token = $stream->nextIf(Twig_Token::NAME_TYPE)) {
+        if ($token = $stream->nextIf(/* Twig_Token::NAME_TYPE */ 5)) {
             $value = $token->getValue();
 
             if ($value != $name) {
@@ -39,7 +39,7 @@ final class Twig_TokenParser_Macro extends Twig_TokenParser
             }
         }
         $this->parser->popLocalScope();
-        $stream->expect(Twig_Token::BLOCK_END_TYPE);
+        $stream->expect(/* Twig_Token::BLOCK_END_TYPE */ 3);
 
         $this->parser->setMacro($name, new Twig_Node_Macro($name, new Twig_Node_Body(array($body)), $arguments, $lineno, $this->getTag()));
     }
