@@ -170,6 +170,7 @@ class TwigTestExtension extends Twig_Extension
     {
         return array(
             new Twig_Test('multi word', array($this, 'is_multi_word')),
+            new Twig_Test('test_*', array($this, 'dynamic_test')),
         );
     }
 
@@ -211,6 +212,11 @@ class TwigTestExtension extends Twig_Extension
         return $foo.'/'.$bar.'/'.$item;
     }
 
+    public function dynamic_test($element, $item)
+    {
+        return $element === $item;
+    }
+
     public function escape_something($value)
     {
         return strtoupper($value);
